==> zio-aws-mgn_2.13-7.21.15.4-sources.jar: zio/aws/mgn/model/package.scala <==
package zio.aws.mgn
import zio.prelude.Subtype
import zio.aws.mgn.model.primitives.{
  SecurityGroupID,
  BoundedString,
  JobID,
  TagValue,
  ExportID,
  ImportID,
  SsmDocumentParameterName,
  ConnectorID,
  ActionID,
  ReplicationConfigurationTemplateID,
  WaveID,
  SourceServerID,
  LaunchConfigurationTemplateID,
  ApplicationID,
  TagKey
}
import zio.aws.mgn.model.primitives.BandwidthThrottling.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ARN extends Subtype[String]
    type ARN = zio.aws.mgn.model.primitives.ARN.Type
    object AccountID extends Subtype[String]
    type AccountID = zio.aws.mgn.model.primitives.AccountID.Type
    object ActionDescription extends Subtype[String]
    type ActionDescription = zio.aws.mgn.model.primitives.ActionDescription.Type
    object ActionID extends Subtype[String]
    type ActionID = zio.aws.mgn.model.primitives.ActionID.Type
    object ActionName extends Subtype[String]
    type ActionName = zio.aws.mgn.model.primitives.ActionName.Type
    object ApplicationDescription extends Subtype[String]
    type ApplicationDescription =
      zio.aws.mgn.model.primitives.ApplicationDescription.Type
    object ApplicationID extends Subtype[String]
    type ApplicationID = zio.aws.mgn.model.primitives.ApplicationID.Type
    object ApplicationName extends Subtype[String]
    type ApplicationName = zio.aws.mgn.model.primitives.ApplicationName.Type
    object BandwidthThrottling extends Subtype[Long]
    type BandwidthThrottling =
      zio.aws.mgn.model.primitives.BandwidthThrottling.Type
    object BoundedString extends Subtype[String]
    type BoundedString = zio.aws.mgn.model.primitives.BoundedString.Type
    object ClientIdempotencyToken extends Subtype[String]
    type ClientIdempotencyToken =
      zio.aws.mgn.model.primitives.ClientIdempotencyToken.Type
    object CloudWatchLogGroupName extends Subtype[String]
    type CloudWatchLogGroupName =
      zio.aws.mgn.model.primitives.CloudWatchLogGroupName.Type
    object ConnectorArn extends Subtype[String]
    type ConnectorArn = zio.aws.mgn.model.primitives.ConnectorArn.Type
    object ConnectorID extends Subtype[String]
    type ConnectorID = zio.aws.mgn.model.primitives.ConnectorID.Type
    object ConnectorName extends Subtype[String]
    type ConnectorName = zio.aws.mgn.model.primitives.ConnectorName.Type
    object DocumentVersion extends Subtype[String]
    type DocumentVersion = zio.aws.mgn.model.primitives.DocumentVersion.Type
    object EC2InstanceID extends Subtype[String]
    type EC2InstanceID = zio.aws.mgn.model.primitives.EC2InstanceID.Type
    object EC2InstanceType extends Subtype[String]
    type EC2InstanceType = zio.aws.mgn.model.primitives.EC2InstanceType.Type
    object EC2LaunchConfigurationTemplateID extends Subtype[String]
    type EC2LaunchConfigurationTemplateID =
      zio.aws.mgn.model.primitives.EC2LaunchConfigurationTemplateID.Type
    object ExportID extends Subtype[String]
    type ExportID = zio.aws.mgn.model.primitives.ExportID.Type
    object ISO8601DatetimeString extends Subtype[String]
    type ISO8601DatetimeString =
      zio.aws.mgn.model.primitives.ISO8601DatetimeString.Type
    object ISO8601DurationString extends Subtype[String]
    type ISO8601DurationString =
      zio.aws.mgn.model.primitives.ISO8601DurationString.Type
    object ImportID extends Subtype[String]
    type ImportID = zio.aws.mgn.model.primitives.ImportID.Type
    object Iops extends Subtype[Long]
    type Iops = zio.aws.mgn.model.primitives.Iops.Type
    object JmesPathString extends Subtype[String]
    type JmesPathString = zio.aws.mgn.model.primitives.JmesPathString.Type
    object JobID extends Subtype[String]
    type JobID = zio.aws.mgn.model.primitives.JobID.Type
    object LargeBoundedString extends Subtype[String]
    type LargeBoundedString =
      zio.aws.mgn.model.primitives.LargeBoundedString.Type
    object LaunchConfigurationTemplateID extends Subtype[String]
    type LaunchConfigurationTemplateID =
      zio.aws.mgn.model.primitives.LaunchConfigurationTemplateID.Type
    object MaxResultsType extends Subtype[Int]
    type MaxResultsType = zio.aws.mgn.model.primitives.MaxResultsType.Type
    object OperatingSystemString extends Subtype[String]
    type OperatingSystemString =
      zio.aws.mgn.model.primitives.OperatingSystemString.Type
    object OrderType extends Subtype[Int]
    type OrderType = zio.aws.mgn.model.primitives.OrderType.Type
    object PaginationToken extends Subtype[String]
    type PaginationToken = zio.aws.mgn.model.primitives.PaginationToken.Type
    object PositiveInteger extends Subtype[Long]
    type PositiveInteger = zio.aws.mgn.model.primitives.PositiveInteger.Type
    object ReplicationConfigurationTemplateID extends Subtype[String]
    type ReplicationConfigurationTemplateID =
      zio.aws.mgn.model.primitives.ReplicationConfigurationTemplateID.Type
    object S3BucketName extends Subtype[String]
    type S3BucketName = zio.aws.mgn.model.primitives.S3BucketName.Type
    object S3Key extends Subtype[String]
    type S3Key = zio.aws.mgn.model.primitives.S3Key.Type
    object S3LogBucketName extends Subtype[String]
    type S3LogBucketName = zio.aws.mgn.model.primitives.S3LogBucketName.Type
    object SecretArn extends Subtype[String]
    type SecretArn = zio.aws.mgn.model.primitives.SecretArn.Type
    object SecurityGroupID extends Subtype[String]
    type SecurityGroupID = zio.aws.mgn.model.primitives.SecurityGroupID.Type
    object SmallBoundedString extends Subtype[String]
    type SmallBoundedString =
      zio.aws.mgn.model.primitives.SmallBoundedString.Type
    object SourceServerID extends Subtype[String]
    type SourceServerID = zio.aws.mgn.model.primitives.SourceServerID.Type
    object SsmDocumentName extends Subtype[String]
    type SsmDocumentName = zio.aws.mgn.model.primitives.SsmDocumentName.Type
    object SsmDocumentParameterName extends Subtype[String]
    type SsmDocumentParameterName =
      zio.aws.mgn.model.primitives.SsmDocumentParameterName.Type
    object SsmInstanceID extends Subtype[String]
    type SsmInstanceID = zio.aws.mgn.model.primitives.SsmInstanceID.Type
    object SsmParameterStoreParameterName extends Subtype[String]
    type SsmParameterStoreParameterName =
      zio.aws.mgn.model.primitives.SsmParameterStoreParameterName.Type
    object StrictlyPositiveInteger extends Subtype[Int]
    type StrictlyPositiveInteger =
      zio.aws.mgn.model.primitives.StrictlyPositiveInteger.Type
    object SubnetID extends Subtype[String]
    type SubnetID = zio.aws.mgn.model.primitives.SubnetID.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.mgn.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.mgn.model.primitives.TagValue.Type
    object Throughput extends Subtype[Long]
    type Throughput = zio.aws.mgn.model.primitives.Throughput.Type
    object VcenterClientID extends Subtype[String]
    type VcenterClientID = zio.aws.mgn.model.primitives.VcenterClientID.Type
    object WaveDescription extends Subtype[String]
    type WaveDescription = zio.aws.mgn.model.primitives.WaveDescription.Type
    object WaveID extends Subtype[String]
    type WaveID = zio.aws.mgn.model.primitives.WaveID.Type
    object WaveName extends Subtype[String]
    type WaveName = zio.aws.mgn.model.primitives.WaveName.Type
  }
  type ActionIDs = List[ActionID]
  type ApplicationIDs = List[ApplicationID]
  type ApplicationIDsFilter = List[ApplicationID]
  type ApplicationsList = List[zio.aws.mgn.model.Application]
  type AssociateSourceServersRequestSourceServerIDs = List[SourceServerID]
  type ConnectorIDsFilter = List[ConnectorID]
  type ConnectorsList = List[zio.aws.mgn.model.Connector]
  type Cpus = List[zio.aws.mgn.model.CPU]
  type DataReplicationInfoReplicatedDisks =
    List[zio.aws.mgn.model.DataReplicationInfoReplicatedDisk]
  type DataReplicationInitiationSteps =
    List[zio.aws.mgn.model.DataReplicationInitiationStep]
  type DescribeJobsRequestFiltersJobIDs = List[JobID]
  type DescribeSourceServersRequestApplicationIDs = List[ApplicationID]
  type DescribeSourceServersRequestFiltersIDs = List[SourceServerID]
  type DisassociateSourceServersRequestSourceServerIDs = List[SourceServerID]
  type Disks = List[zio.aws.mgn.model.Disk]
  type ExportErrors = List[zio.aws.mgn.model.ExportTaskError]
  type ExportsList = List[zio.aws.mgn.model.ExportTask]
  type IPsList = List[BoundedString]
  type ImportErrors = List[zio.aws.mgn.model.ImportTaskError]
  type ImportIDsFilter = List[ImportID]
  type ImportList = List[zio.aws.mgn.model.ImportTask]
  type JobLogs = List[zio.aws.mgn.model.JobLog]
  type JobsList = List[zio.aws.mgn.model.Job]
  type LaunchConfigurationTemplateIDs = List[LaunchConfigurationTemplateID]
  type LaunchConfigurationTemplates =
    List[zio.aws.mgn.model.LaunchConfigurationTemplate]
  type LifeCycleStates = List[zio.aws.mgn.model.LifeCycleState]
  type ListExportsRequestFiltersExportIDs = List[ExportID]
  type ManagedAccounts = List[zio.aws.mgn.model.ManagedAccount]
  type NetworkInterfaces = List[zio.aws.mgn.model.NetworkInterface]
  type ParticipatingServers = List[zio.aws.mgn.model.ParticipatingServer]
  type PostLaunchActionsLaunchStatusList =
    List[zio.aws.mgn.model.JobPostLaunchActionsLaunchStatus]
  type ReplicationConfigurationReplicatedDisks =
    List[zio.aws.mgn.model.ReplicationConfigurationReplicatedDisk]
  type ReplicationConfigurationTemplateIDs =
    List[ReplicationConfigurationTemplateID]
  type ReplicationConfigurationTemplates =
    List[zio.aws.mgn.model.ReplicationConfigurationTemplate]
  type ReplicationServersSecurityGroupsIDs = List[SecurityGroupID]
  type ReplicationTypes = List[zio.aws.mgn.model.ReplicationType]
  type SourceServerActionDocuments =
    List[zio.aws.mgn.model.SourceServerActionDocument]
  type SourceServersList = List[zio.aws.mgn.model.SourceServer]
  type SsmDocumentExternalParameters =
    Map[SsmDocumentParameterName, zio.aws.mgn.model.SsmExternalParameter]
  type SsmDocumentParameters = Map[SsmDocumentParameterName, Iterable[
    zio.aws.mgn.model.SsmParameterStoreParameter
  ]]
  type SsmDocuments = List[zio.aws.mgn.model.SsmDocument]
  type SsmParameterStoreParameters =
    List[zio.aws.mgn.model.SsmParameterStoreParameter]
  type StartCutoverRequestSourceServerIDs = List[SourceServerID]
  type StartTestRequestSourceServerIDs = List[SourceServerID]
  type TagKeys = List[TagKey]
  type TagsMap = Map[TagKey, TagValue]
  type TemplateActionDocuments = List[zio.aws.mgn.model.TemplateActionDocument]
  type TerminateTargetInstancesRequestSourceServerIDs = List[SourceServerID]
  type VcenterClientList = List[zio.aws.mgn.model.VcenterClient]
  type WaveIDsFilter = List[WaveID]
  type WavesList = List[zio.aws.mgn.model.Wave]
}

==> zio-aws-mgn_2.13-7.28.29.8-sources.jar: zio/aws/mgn/model/package.scala <==
package zio.aws.mgn
import zio.prelude.Subtype
import zio.aws.mgn.model.primitives.{
  SecurityGroupID,
  BoundedString,
  JobID,
  TagValue,
  ExportID,
  ImportID,
  SsmDocumentParameterName,
  ConnectorID,
  ActionID,
  ReplicationConfigurationTemplateID,
  WaveID,
  SourceServerID,
  LaunchConfigurationTemplateID,
  ApplicationID,
  TagKey
}
import zio.aws.mgn.model.primitives.BandwidthThrottling.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ARN extends zio.prelude.Subtype[String]
    type ARN = zio.aws.mgn.model.primitives.ARN.Type
    object AccountID extends zio.prelude.Subtype[String]
    type AccountID = zio.aws.mgn.model.primitives.AccountID.Type
    object ActionDescription extends zio.prelude.Subtype[String]
    type ActionDescription = zio.aws.mgn.model.primitives.ActionDescription.Type
    object ActionID extends zio.prelude.Subtype[String]
    type ActionID = zio.aws.mgn.model.primitives.ActionID.Type
    object ActionName extends zio.prelude.Subtype[String]
    type ActionName = zio.aws.mgn.model.primitives.ActionName.Type
    object ApplicationDescription extends zio.prelude.Subtype[String]
    type ApplicationDescription =
      zio.aws.mgn.model.primitives.ApplicationDescription.Type
    object ApplicationID extends zio.prelude.Subtype[String]
    type ApplicationID = zio.aws.mgn.model.primitives.ApplicationID.Type
    object ApplicationName extends zio.prelude.Subtype[String]
    type ApplicationName = zio.aws.mgn.model.primitives.ApplicationName.Type
    object BandwidthThrottling extends zio.prelude.Subtype[Long]
    type BandwidthThrottling =
      zio.aws.mgn.model.primitives.BandwidthThrottling.Type
    object BoundedString extends zio.prelude.Subtype[String]
    type BoundedString = zio.aws.mgn.model.primitives.BoundedString.Type
    object ClientIdempotencyToken extends zio.prelude.Subtype[String]
    type ClientIdempotencyToken =
      zio.aws.mgn.model.primitives.ClientIdempotencyToken.Type
    object CloudWatchLogGroupName extends zio.prelude.Subtype[String]
    type CloudWatchLogGroupName =
      zio.aws.mgn.model.primitives.CloudWatchLogGroupName.Type
    object ConnectorArn extends zio.prelude.Subtype[String]
    type ConnectorArn = zio.aws.mgn.model.primitives.ConnectorArn.Type
    object ConnectorID extends zio.prelude.Subtype[String]
    type ConnectorID = zio.aws.mgn.model.primitives.ConnectorID.Type
    object ConnectorName extends zio.prelude.Subtype[String]
    type ConnectorName = zio.aws.mgn.model.primitives.ConnectorName.Type
    object DocumentVersion extends zio.prelude.Subtype[String]
    type DocumentVersion = zio.aws.mgn.model.primitives.DocumentVersion.Type
    object EC2InstanceID extends zio.prelude.Subtype[String]
    type EC2InstanceID = zio.aws.mgn.model.primitives.EC2InstanceID.Type
    object EC2InstanceType extends zio.prelude.Subtype[String]
    type EC2InstanceType = zio.aws.mgn.model.primitives.EC2InstanceType.Type
    object EC2LaunchConfigurationTemplateID extends zio.prelude.Subtype[String]
    type EC2LaunchConfigurationTemplateID =
      zio.aws.mgn.model.primitives.EC2LaunchConfigurationTemplateID.Type
    object ExportID extends zio.prelude.Subtype[String]
    type ExportID = zio.aws.mgn.model.primitives.ExportID.Type
    object ISO8601DatetimeString extends zio.prelude.Subtype[String]
    type ISO8601DatetimeString =
      zio.aws.mgn.model.primitives.ISO8601DatetimeString.Type
    object ISO8601DurationString extends zio.prelude.Subtype[String]
    type ISO8601DurationString =
      zio.aws.mgn.model.primitives.ISO8601DurationString.Type
    object ImportID extends zio.prelude.Subtype[String]
    type ImportID = zio.aws.mgn.model.primitives.ImportID.Type
    object Iops extends zio.prelude.Subtype[Long]
    type Iops = zio.aws.mgn.model.primitives.Iops.Type
    object JmesPathString extends zio.prelude.Subtype[String]
    type JmesPathString = zio.aws.mgn.model.primitives.JmesPathString.Type
    object JobID extends zio.prelude.Subtype[String]
    type JobID = zio.aws.mgn.model.primitives.JobID.Type
    object LargeBoundedString extends zio.prelude.Subtype[String]
    type LargeBoundedString =
      zio.aws.mgn.model.primitives.LargeBoundedString.Type
    object LaunchConfigurationTemplateID extends zio.prelude.Subtype[String]
    type LaunchConfigurationTemplateID =
      zio.aws.mgn.model.primitives.LaunchConfigurationTemplateID.Type
    object MaxResultsType extends zio.prelude.Subtype[Int]
    type MaxResultsType = zio.aws.mgn.model.primitives.MaxResultsType.Type
    object OperatingSystemString extends zio.prelude.Subtype[String]
    type OperatingSystemString =
      zio.aws.mgn.model.primitives.OperatingSystemString.Type
    object OrderType extends zio.prelude.Subtype[Int]
    type OrderType = zio.aws.mgn.model.primitives.OrderType.Type
    object PaginationToken extends zio.prelude.Subtype[String]
    type PaginationToken = zio.aws.mgn.model.primitives.PaginationToken.Type
    object PositiveInteger extends zio.prelude.Subtype[Long]
    type PositiveInteger = zio.aws.mgn.model.primitives.PositiveInteger.Type
    object ReplicationConfigurationTemplateID
        extends zio.prelude.Subtype[String]
    type ReplicationConfigurationTemplateID =
      zio.aws.mgn.model.primitives.ReplicationConfigurationTemplateID.Type
    object S3BucketName extends zio.prelude.Subtype[String]
    type S3BucketName = zio.aws.mgn.model.primitives.S3BucketName.Type
    object S3Key extends zio.prelude.Subtype[String]
    type S3Key = zio.aws.mgn.model.primitives.S3Key.Type
    object S3LogBucketName extends zio.prelude.Subtype[String]
    type S3LogBucketName = zio.aws.mgn.model.primitives.S3LogBucketName.Type
    object SecretArn extends zio.prelude.Subtype[String]
    type SecretArn = zio.aws.mgn.model.primitives.SecretArn.Type
    object SecurityGroupID extends zio.prelude.Subtype[String]
    type SecurityGroupID = zio.aws.mgn.model.primitives.SecurityGroupID.Type
    object SmallBoundedString extends zio.prelude.Subtype[String]
    type SmallBoundedString =
      zio.aws.mgn.model.primitives.SmallBoundedString.Type
    object SourceServerID extends zio.prelude.Subtype[String]
    type SourceServerID = zio.aws.mgn.model.primitives.SourceServerID.Type
    object SsmDocumentName extends zio.prelude.Subtype[String]
    type SsmDocumentName = zio.aws.mgn.model.primitives.SsmDocumentName.Type
    object SsmDocumentParameterName extends zio.prelude.Subtype[String]
    type SsmDocumentParameterName =
      zio.aws.mgn.model.primitives.SsmDocumentParameterName.Type
    object SsmInstanceID extends zio.prelude.Subtype[String]
    type SsmInstanceID = zio.aws.mgn.model.primitives.SsmInstanceID.Type
    object SsmParameterStoreParameterName extends zio.prelude.Subtype[String]
    type SsmParameterStoreParameterName =
      zio.aws.mgn.model.primitives.SsmParameterStoreParameterName.Type
    object StrictlyPositiveInteger extends zio.prelude.Subtype[Int]
    type StrictlyPositiveInteger =
      zio.aws.mgn.model.primitives.StrictlyPositiveInteger.Type
    object SubnetID extends zio.prelude.Subtype[String]
    type SubnetID = zio.aws.mgn.model.primitives.SubnetID.Type
    object TagKey extends zio.prelude.Subtype[String]
    type TagKey = zio.aws.mgn.model.primitives.TagKey.Type
    object TagValue extends zio.prelude.Subtype[String]
    type TagValue = zio.aws.mgn.model.primitives.TagValue.Type
    object Throughput extends zio.prelude.Subtype[Long]
    type Throughput = zio.aws.mgn.model.primitives.Throughput.Type
    object VcenterClientID extends zio.prelude.Subtype[String]
    type VcenterClientID = zio.aws.mgn.model.primitives.VcenterClientID.Type
    object WaveDescription extends zio.prelude.Subtype[String]
    type WaveDescription = zio.aws.mgn.model.primitives.WaveDescription.Type
    object WaveID extends zio.prelude.Subtype[String]
    type WaveID = zio.aws.mgn.model.primitives.WaveID.Type
    object WaveName extends zio.prelude.Subtype[String]
    type WaveName = zio.aws.mgn.model.primitives.WaveName.Type
  }
  type ActionIDs = List[ActionID]
  type ApplicationIDs = List[ApplicationID]
  type ApplicationIDsFilter = List[ApplicationID]
  type ApplicationsList = List[zio.aws.mgn.model.Application]
  type AssociateSourceServersRequestSourceServerIDs = List[SourceServerID]
  type ConnectorIDsFilter = List[ConnectorID]
  type ConnectorsList = List[zio.aws.mgn.model.Connector]
  type Cpus = List[zio.aws.mgn.model.CPU]
  type DataReplicationInfoReplicatedDisks =
    List[zio.aws.mgn.model.DataReplicationInfoReplicatedDisk]
  type DataReplicationInitiationSteps =
    List[zio.aws.mgn.model.DataReplicationInitiationStep]
  type DescribeJobsRequestFiltersJobIDs = List[JobID]
  type DescribeSourceServersRequestApplicationIDs = List[ApplicationID]
  type DescribeSourceServersRequestFiltersIDs = List[SourceServerID]
  type DisassociateSourceServersRequestSourceServerIDs = List[SourceServerID]
  type Disks = List[zio.aws.mgn.model.Disk]
  type ExportErrors = List[zio.aws.mgn.model.ExportTaskError]
  type ExportsList = List[zio.aws.mgn.model.ExportTask]
  type IPsList = List[BoundedString]
  type ImportErrors = List[zio.aws.mgn.model.ImportTaskError]
  type ImportIDsFilter = List[ImportID]
  type ImportList = List[zio.aws.mgn.model.ImportTask]
  type JobLogs = List[zio.aws.mgn.model.JobLog]
  type JobsList = List[zio.aws.mgn.model.Job]
  type LaunchConfigurationTemplateIDs = List[LaunchConfigurationTemplateID]
  type LaunchConfigurationTemplates =
    List[zio.aws.mgn.model.LaunchConfigurationTemplate]
  type LifeCycleStates = List[zio.aws.mgn.model.LifeCycleState]
  type ListExportsRequestFiltersExportIDs = List[ExportID]
  type ManagedAccounts = List[zio.aws.mgn.model.ManagedAccount]
  type NetworkInterfaces = List[zio.aws.mgn.model.NetworkInterface]
  type ParticipatingServers = List[zio.aws.mgn.model.ParticipatingServer]
  type PostLaunchActionsLaunchStatusList =
    List[zio.aws.mgn.model.JobPostLaunchActionsLaunchStatus]
  type ReplicationConfigurationReplicatedDisks =
    List[zio.aws.mgn.model.ReplicationConfigurationReplicatedDisk]
  type ReplicationConfigurationTemplateIDs =
    List[ReplicationConfigurationTemplateID]
  type ReplicationConfigurationTemplates =
    List[zio.aws.mgn.model.ReplicationConfigurationTemplate]
  type ReplicationServersSecurityGroupsIDs = List[SecurityGroupID]
  type ReplicationTypes = List[zio.aws.mgn.model.ReplicationType]
  type SourceServerActionDocuments =
    List[zio.aws.mgn.model.SourceServerActionDocument]
  type SourceServersList = List[zio.aws.mgn.model.SourceServer]
  type SsmDocumentExternalParameters =
    Map[SsmDocumentParameterName, zio.aws.mgn.model.SsmExternalParameter]
  type SsmDocumentParameters = Map[SsmDocumentParameterName, Iterable[
    zio.aws.mgn.model.SsmParameterStoreParameter
  ]]
  type SsmDocuments = List[zio.aws.mgn.model.SsmDocument]
  type SsmParameterStoreParameters =
    List[zio.aws.mgn.model.SsmParameterStoreParameter]
  type StartCutoverRequestSourceServerIDs = List[SourceServerID]
  type StartTestRequestSourceServerIDs = List[SourceServerID]
  type TagKeys = List[TagKey]
  type TagsMap = Map[TagKey, TagValue]
  type TemplateActionDocuments = List[zio.aws.mgn.model.TemplateActionDocument]
  type TerminateTargetInstancesRequestSourceServerIDs = List[SourceServerID]
  type VcenterClientList = List[zio.aws.mgn.model.VcenterClient]
  type WaveIDsFilter = List[WaveID]
  type WavesList = List[zio.aws.mgn.model.Wave]
}
